@@ -5,7 +5,7 @@ from dataclasses import (
     dataclass,
     field as _field,
     fields,
-    make_dataclass,
+    make_dataclass as _make_dataclass,
     replace,
 )
 import functools
@@ -23,7 +23,7 @@ __all__ = (
     'mutable',
     'replace',
 )
-__version__ = '4.2.1'
+__version__ = '4.3.0'
 
 _METHODS = 'asdict', 'astuple', 'fields', 'replace'
 _CLASS_METHODS = {'field_names', 'fields'}
@@ -62,6 +62,11 @@ def add_methods(dcls):
     return dcls
 
 
+@functools.wraps(_make_dataclass)
+def make_dataclass(*a, **ka):
+    return add_methods(_make_dataclass(*a, **ka))
+
+
 hidden = functools.partial(field, compare=False, init=False, repr=False)
 immutable = functools.partial(mutable, frozen=True)
 xmod(immutable, 'datacls')
